============================================================
gdpnum: Numeric Computation of Gaussian Differential Privacy
============================================================

.. include:: ../README.md
   :parser: myst_parser.sphinx_

Additional Documentation
=======================

This documentation provides more detailed information beyond what's in the README:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage/basic
   usage/dpsgd
   usage/general
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`